@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.07_1';
+our $VERSION = '0.07_2';
 
 =head1 NAME
 
@@ -1743,6 +1743,31 @@ sub links {
 	return $self->{inform}->{links};
 }
 
+=head2 cacheusage
+
+Return cache usage for a node
+
+  my $cache = $node->cacheusage;
+
+=cut
+
+sub cacheusage {
+	my $self = shift;
+
+	return unless ($self->{url});
+
+	my $resbody;
+	my $rv = $self->shuttle_url( $self->{url} . '/cacheusage',
+		'text/plain',
+		undef,
+		\$resbody,
+	);
+
+	return if ($rv != 200 || !$resbody);
+
+	return $resbody;
+}
+
 =head2 master
 
 Set actions on Hyper Estraier node master (C<estmaster> process)
